==> flink-1.17.0-src.tgz: flink-1.17.0/flink-runtime/src/test/java/org/apache/flink/runtime/io/network/DataExchangeModeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.io.network;

import org.apache.flink.api.common.ExecutionMode;

import org.junit.Test;

import static org.junit.Assert.assertNotNull;

/** This test verifies that the data exchange modes are defined for every execution mode. */
public class DataExchangeModeTest {

    @Test
    public void testForward() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertNotNull(DataExchangeMode.getForForwardExchange(mode));
        }
    }

    @Test
    public void testShuffleAndBroadcast() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertNotNull(DataExchangeMode.getForShuffleOrBroadcast(mode));
        }
    }

    @Test
    public void testPipelineBreaking() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertNotNull(DataExchangeMode.getPipelineBreakingExchange(mode));
        }
    }
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-runtime/src/test/java/org/apache/flink/runtime/io/network/DataExchangeModeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.io.network;

import org.apache.flink.api.common.ExecutionMode;

import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/** This test verifies that the data exchange modes are defined for every execution mode. */
class DataExchangeModeTest {

    @Test
    void testForward() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertThat(DataExchangeMode.getForForwardExchange(mode)).isNotNull();
        }
    }

    @Test
    void testShuffleAndBroadcast() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertThat(DataExchangeMode.getForShuffleOrBroadcast(mode)).isNotNull();
        }
    }

    @Test
    void testPipelineBreaking() {
        for (ExecutionMode mode : ExecutionMode.values()) {
            assertThat(DataExchangeMode.getPipelineBreakingExchange(mode)).isNotNull();
        }
    }
}
